summaryrefslogtreecommitdiffstats
path: root/smb4k/searchdlg/smb4ksearchdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'smb4k/searchdlg/smb4ksearchdialog.h')
-rw-r--r--smb4k/searchdlg/smb4ksearchdialog.h23
1 files changed, 12 insertions, 11 deletions
diff --git a/smb4k/searchdlg/smb4ksearchdialog.h b/smb4k/searchdlg/smb4ksearchdialog.h
index 2b0f2eb..19d2526 100644
--- a/smb4k/searchdlg/smb4ksearchdialog.h
+++ b/smb4k/searchdlg/smb4ksearchdialog.h
@@ -30,9 +30,9 @@
#include <config.h>
#endif
-// Qt includes
-#include <qwidget.h>
-#include <qstring.h>
+// TQt includes
+#include <tqwidget.h>
+#include <tqstring.h>
// KDE includes
#include <klistview.h>
@@ -50,19 +50,20 @@ class Smb4KHostItem;
*/
-class Smb4KSearchDialog : public QWidget
+class Smb4KSearchDialog : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* The constructor.
*
* @param parent The parent widget
*
* @param name The name of this widget
*/
- Smb4KSearchDialog( QWidget *parent = 0, const char *name = 0 );
+ Smb4KSearchDialog( TQWidget *tqparent = 0, const char *name = 0 );
/**
* The destructor.
@@ -81,7 +82,7 @@ class Smb4KSearchDialog : public QWidget
*
* @returns the search string.
*/
- const QString &searchString();
+ const TQString &searchString();
/**
* This function returns a pointer to the list view of this widget.
@@ -120,7 +121,7 @@ class Smb4KSearchDialog : public QWidget
*
* @param text The text input
*/
- void slotTextChanged( const QString &text );
+ void slotTextChanged( const TQString &text );
/**
* This slot is activated when a button in the tool bar is pressed.
@@ -143,7 +144,7 @@ class Smb4KSearchDialog : public QWidget
* @param item The list box item that the user clicked or NULL if
* he clicked onto the viewport.
*/
- void slotItemClicked( QListViewItem *item );
+ void slotItemClicked( TQListViewItem *item );
/**
* This slot is activated when the selection changed in the list view.
@@ -151,13 +152,13 @@ class Smb4KSearchDialog : public QWidget
*
* @param item The list box item that's currently selected
*/
- void slotSelectionChanged( QListViewItem *item );
+ void slotSelectionChanged( TQListViewItem *item );
private:
/**
* The current search string
*/
- QString m_search_string;
+ TQString m_search_string;
/**
* The list box of this widget
@@ -50,19 +50,20 @@ class Smb4KHostItem;
* The constructor.
*
- * @param parent The parent widget
+ * @param tqparent The tqparent widget
*
* @param name The name of this widget